@@ -65,6 +65,7 @@
 #include <QtNetwork/qdtls.h>
 #include <QtNetwork/qnetworkaccessmanager.h>
 #include <QtNetwork/qnetworkinterface.h>
+#include <QtNetwork/qnetworkinformation.h>
 #include <QtNetwork/qsslpresharedkeyauthenticator.h>
 #include <QtNetwork/qlocalsocket.h>
 #include <QtNetwork/qnetworkcookiejar.h>
@@ -72,11 +73,13 @@
 #include <QtNetwork/qnetworkdatagram.h>
 #include <QtNetwork/qsslkey.h>
 #include <QtNetwork/qsslerror.h>
+#include <QtNetwork/qsslellipticcurve.h>
 #include <QtNetwork/qauthenticator.h>
 #include <QtNetwork/qabstractsocket.h>
 #include <QtNetwork/qnetworkrequest.h>
 #include <QtNetwork/qssl.h>
 #include <QtNetwork/qnetworkreply.h>
+#include <QtNetwork/qhttp2configuration.h>
 #include <QtNetwork/qhstspolicy.h>
 #include <QtNetwork/qudpsocket.h>
 #include <QtNetwork/qtcpsocket.h>
@@ -86,6 +89,7 @@
 #include <QtNetwork/qsslcertificate.h>
 #include <QtNetwork/qlocalserver.h>
 // Conversion Includes - Primitive Types
+#include <QAnyStringView>
 #include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
@@ -96,6 +100,7 @@
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
@@ -111,9 +116,9 @@ enum : int {
     SBK_QABSTRACTSOCKET_SOCKETSTATE_IDX                      = 7,
     SBK_QABSTRACTSOCKET_SOCKETOPTION_IDX                     = 6,
     SBK_QABSTRACTSOCKET_BINDFLAG_IDX                         = 2,
-    SBK_QFLAGS_QABSTRACTSOCKET_BINDFLAG_IDX                  = 21,
+    SBK_QFLAGS_QABSTRACTSOCKET_BINDFLAG_IDX                  = 22,
     SBK_QABSTRACTSOCKET_PAUSEMODE_IDX                        = 4,
-    SBK_QFLAGS_QABSTRACTSOCKET_PAUSEMODE_IDX                 = 22,
+    SBK_QFLAGS_QABSTRACTSOCKET_PAUSEMODE_IDX                 = 23,
     SBK_QABSTRACTSOCKET_IDX                                  = 1,
     SBK_QAUTHENTICATOR_IDX                                   = 9,
     SBK_QDNSDOMAINNAMERECORD_IDX                             = 10,
@@ -126,94 +131,103 @@ enum : int {
     SBK_QDNSTEXTRECORD_IDX                                   = 17,
     SBK_QDTLS_HANDSHAKESTATE_IDX                             = 19,
     SBK_QDTLS_IDX                                            = 18,
-    SBK_QHOSTADDRESS_SPECIALADDRESS_IDX                      = 31,
-    SBK_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX                  = 30,
-    SBK_QFLAGS_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX           = 23,
-    SBK_QHOSTADDRESS_IDX                                     = 29,
-    SBK_QHOSTINFO_HOSTINFOERROR_IDX                          = 33,
-    SBK_QHOSTINFO_IDX                                        = 32,
-    SBK_QHSTSPOLICY_POLICYFLAG_IDX                           = 35,
-    SBK_QFLAGS_QHSTSPOLICY_POLICYFLAG_IDX                    = 24,
-    SBK_QHSTSPOLICY_IDX                                      = 34,
-    SBK_QHTTPMULTIPART_CONTENTTYPE_IDX                       = 37,
-    SBK_QHTTPMULTIPART_IDX                                   = 36,
-    SBK_QHTTPPART_IDX                                        = 38,
-    SBK_QIPV6ADDRESS_IDX                                     = 39,
-    SBK_QLOCALSERVER_SOCKETOPTION_IDX                        = 41,
-    SBK_QFLAGS_QLOCALSERVER_SOCKETOPTION_IDX                 = 25,
-    SBK_QLOCALSERVER_IDX                                     = 40,
-    SBK_QLOCALSOCKET_LOCALSOCKETERROR_IDX                    = 43,
-    SBK_QLOCALSOCKET_LOCALSOCKETSTATE_IDX                    = 44,
-    SBK_QLOCALSOCKET_IDX                                     = 42,
-    SBK_QNETWORKACCESSMANAGER_OPERATION_IDX                  = 46,
-    SBK_QNETWORKACCESSMANAGER_IDX                            = 45,
-    SBK_QNETWORKADDRESSENTRY_DNSELIGIBILITYSTATUS_IDX        = 48,
-    SBK_QNETWORKADDRESSENTRY_IDX                             = 47,
-    SBK_QNETWORKCACHEMETADATA_IDX                            = 49,
-    SBK_QNETWORKCOOKIE_RAWFORM_IDX                           = 51,
-    SBK_QNETWORKCOOKIE_SAMESITE_IDX                          = 52,
-    SBK_QNETWORKCOOKIE_IDX                                   = 50,
-    SBK_QNETWORKCOOKIEJAR_IDX                                = 53,
-    SBK_QNETWORKDATAGRAM_IDX                                 = 54,
-    SBK_QNETWORKDISKCACHE_IDX                                = 55,
-    SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX                  = 57,
-    SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG_IDX           = 26,
-    SBK_QNETWORKINTERFACE_INTERFACETYPE_IDX                  = 58,
-    SBK_QNETWORKINTERFACE_IDX                                = 56,
-    SBK_QNETWORKPROXY_PROXYTYPE_IDX                          = 61,
-    SBK_QNETWORKPROXY_CAPABILITY_IDX                         = 60,
-    SBK_QFLAGS_QNETWORKPROXY_CAPABILITY_IDX                  = 27,
-    SBK_QNETWORKPROXY_IDX                                    = 59,
-    SBK_QNETWORKPROXYFACTORY_IDX                             = 62,
-    SBK_QNETWORKPROXYQUERY_QUERYTYPE_IDX                     = 64,
-    SBK_QNETWORKPROXYQUERY_IDX                               = 63,
-    SBK_QNETWORKREPLY_NETWORKERROR_IDX                       = 66,
-    SBK_QNETWORKREPLY_IDX                                    = 65,
-    SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX                     = 70,
-    SBK_QNETWORKREQUEST_ATTRIBUTE_IDX                        = 68,
-    SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX                 = 69,
-    SBK_QNETWORKREQUEST_LOADCONTROL_IDX                      = 71,
-    SBK_QNETWORKREQUEST_PRIORITY_IDX                         = 72,
-    SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX                   = 73,
-    SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX          = 74,
-    SBK_QNETWORKREQUEST_IDX                                  = 67,
-    SBK_QOCSPRESPONSE_IDX                                    = 76,
-    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 78,
-    SBK_QSSL_KEYTYPE_IDX                                     = 86,
-    SBK_QSSL_ENCODINGFORMAT_IDX                              = 83,
-    SBK_QSSL_KEYALGORITHM_IDX                                = 85,
-    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 82,
-    SBK_QSSL_SSLPROTOCOL_IDX                                 = 88,
-    SBK_QSSL_SSLOPTION_IDX                                   = 87,
-    SBK_QFLAGS_QSSL_SSLOPTION_IDX                            = 28,
-    SBK_QSSL_ALERTLEVEL_IDX                                  = 80,
-    SBK_QSSL_ALERTTYPE_IDX                                   = 81,
-    SBK_QSSL_IMPLEMENTEDCLASS_IDX                            = 84,
-    SBK_QSSL_SUPPORTEDFEATURE_IDX                            = 89,
-    SBK_QtNetworkQSSL_IDX                                    = 79,
-    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 92,
-    SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX                    = 91,
-    SBK_QSSLCERTIFICATE_IDX                                  = 90,
-    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 93,
-    SBK_QSSLCIPHER_IDX                                       = 94,
-    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 96,
-    SBK_QSSLCONFIGURATION_IDX                                = 95,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 98,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 97,
-    SBK_QSSLERROR_SSLERROR_IDX                               = 100,
-    SBK_QSSLERROR_IDX                                        = 99,
-    SBK_QSSLKEY_IDX                                          = 101,
-    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 102,
-    SBK_QSSLSOCKET_SSLMODE_IDX                               = 105,
-    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 104,
-    SBK_QSSLSOCKET_IDX                                       = 103,
-    SBK_QTCPSERVER_IDX                                       = 106,
-    SBK_QTCPSOCKET_IDX                                       = 107,
-    SBK_QUDPSOCKET_IDX                                       = 108,
-    SBK_QDTLSERROR_IDX                                       = 20,
-    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 75,
-    SBK_QOCSPREVOCATIONREASON_IDX                            = 77,
-    SBK_QtNetwork_IDX_COUNT                                  = 109
+    SBK_QDTLSCLIENTVERIFIER_IDX                              = 20,
+    SBK_QHOSTADDRESS_SPECIALADDRESS_IDX                      = 34,
+    SBK_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX                  = 33,
+    SBK_QFLAGS_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX           = 24,
+    SBK_QHOSTADDRESS_IDX                                     = 32,
+    SBK_QHOSTINFO_HOSTINFOERROR_IDX                          = 36,
+    SBK_QHOSTINFO_IDX                                        = 35,
+    SBK_QHSTSPOLICY_POLICYFLAG_IDX                           = 38,
+    SBK_QFLAGS_QHSTSPOLICY_POLICYFLAG_IDX                    = 25,
+    SBK_QHSTSPOLICY_IDX                                      = 37,
+    SBK_QHTTP2CONFIGURATION_IDX                              = 39,
+    SBK_QHTTPMULTIPART_CONTENTTYPE_IDX                       = 41,
+    SBK_QHTTPMULTIPART_IDX                                   = 40,
+    SBK_QHTTPPART_IDX                                        = 42,
+    SBK_QIPV6ADDRESS_IDX                                     = 43,
+    SBK_QLOCALSERVER_SOCKETOPTION_IDX                        = 45,
+    SBK_QFLAGS_QLOCALSERVER_SOCKETOPTION_IDX                 = 26,
+    SBK_QLOCALSERVER_IDX                                     = 44,
+    SBK_QLOCALSOCKET_LOCALSOCKETERROR_IDX                    = 47,
+    SBK_QLOCALSOCKET_LOCALSOCKETSTATE_IDX                    = 48,
+    SBK_QLOCALSOCKET_SOCKETOPTION_IDX                        = 49,
+    SBK_QFLAGS_QLOCALSOCKET_SOCKETOPTION_IDX                 = 27,
+    SBK_QLOCALSOCKET_IDX                                     = 46,
+    SBK_QNETWORKACCESSMANAGER_OPERATION_IDX                  = 51,
+    SBK_QNETWORKACCESSMANAGER_IDX                            = 50,
+    SBK_QNETWORKADDRESSENTRY_DNSELIGIBILITYSTATUS_IDX        = 53,
+    SBK_QNETWORKADDRESSENTRY_IDX                             = 52,
+    SBK_QNETWORKCACHEMETADATA_IDX                            = 54,
+    SBK_QNETWORKCOOKIE_RAWFORM_IDX                           = 56,
+    SBK_QNETWORKCOOKIE_SAMESITE_IDX                          = 57,
+    SBK_QNETWORKCOOKIE_IDX                                   = 55,
+    SBK_QNETWORKCOOKIEJAR_IDX                                = 58,
+    SBK_QNETWORKDATAGRAM_IDX                                 = 59,
+    SBK_QNETWORKDISKCACHE_IDX                                = 60,
+    SBK_QNETWORKINFORMATION_REACHABILITY_IDX                 = 63,
+    SBK_QNETWORKINFORMATION_FEATURE_IDX                      = 62,
+    SBK_QFLAGS_QNETWORKINFORMATION_FEATURE_IDX               = 28,
+    SBK_QNETWORKINFORMATION_IDX                              = 61,
+    SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX                  = 65,
+    SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG_IDX           = 29,
+    SBK_QNETWORKINTERFACE_INTERFACETYPE_IDX                  = 66,
+    SBK_QNETWORKINTERFACE_IDX                                = 64,
+    SBK_QNETWORKPROXY_PROXYTYPE_IDX                          = 69,
+    SBK_QNETWORKPROXY_CAPABILITY_IDX                         = 68,
+    SBK_QFLAGS_QNETWORKPROXY_CAPABILITY_IDX                  = 30,
+    SBK_QNETWORKPROXY_IDX                                    = 67,
+    SBK_QNETWORKPROXYFACTORY_IDX                             = 70,
+    SBK_QNETWORKPROXYQUERY_QUERYTYPE_IDX                     = 72,
+    SBK_QNETWORKPROXYQUERY_IDX                               = 71,
+    SBK_QNETWORKREPLY_NETWORKERROR_IDX                       = 74,
+    SBK_QNETWORKREPLY_IDX                                    = 73,
+    SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX                     = 78,
+    SBK_QNETWORKREQUEST_ATTRIBUTE_IDX                        = 76,
+    SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX                 = 77,
+    SBK_QNETWORKREQUEST_LOADCONTROL_IDX                      = 79,
+    SBK_QNETWORKREQUEST_PRIORITY_IDX                         = 80,
+    SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX                   = 81,
+    SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX          = 82,
+    SBK_QNETWORKREQUEST_IDX                                  = 75,
+    SBK_QOCSPRESPONSE_IDX                                    = 84,
+    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 86,
+    SBK_QSSL_KEYTYPE_IDX                                     = 94,
+    SBK_QSSL_ENCODINGFORMAT_IDX                              = 91,
+    SBK_QSSL_KEYALGORITHM_IDX                                = 93,
+    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 90,
+    SBK_QSSL_SSLPROTOCOL_IDX                                 = 96,
+    SBK_QSSL_SSLOPTION_IDX                                   = 95,
+    SBK_QFLAGS_QSSL_SSLOPTION_IDX                            = 31,
+    SBK_QSSL_ALERTLEVEL_IDX                                  = 88,
+    SBK_QSSL_ALERTTYPE_IDX                                   = 89,
+    SBK_QSSL_IMPLEMENTEDCLASS_IDX                            = 92,
+    SBK_QSSL_SUPPORTEDFEATURE_IDX                            = 97,
+    SBK_QtNetworkQSSL_IDX                                    = 87,
+    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 100,
+    SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX                    = 99,
+    SBK_QSSLCERTIFICATE_IDX                                  = 98,
+    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 101,
+    SBK_QSSLCIPHER_IDX                                       = 102,
+    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 104,
+    SBK_QSSLCONFIGURATION_IDX                                = 103,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 106,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 105,
+    SBK_QSSLELLIPTICCURVE_IDX                                = 107,
+    SBK_QSSLERROR_SSLERROR_IDX                               = 109,
+    SBK_QSSLERROR_IDX                                        = 108,
+    SBK_QSSLKEY_IDX                                          = 110,
+    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 111,
+    SBK_QSSLSOCKET_SSLMODE_IDX                               = 114,
+    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 113,
+    SBK_QSSLSOCKET_IDX                                       = 112,
+    SBK_QTCPSERVER_IDX                                       = 115,
+    SBK_QTCPSOCKET_IDX                                       = 116,
+    SBK_QUDPSOCKET_IDX                                       = 117,
+    SBK_QDTLSERROR_IDX                                       = 21,
+    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 83,
+    SBK_QOCSPREVOCATIONREASON_IDX                            = 85,
+    SBK_QtNetwork_IDX_COUNT                                  = 118
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtNetworkTypes;
@@ -230,14 +244,14 @@ enum : int {
     SBK_QTNETWORK_QLIST_QBYTEARRAY_IDX                       = 1, // QList<QByteArray >
     SBK_QTNETWORK_QMAP_QBYTEARRAY_QVARIANT_IDX               = 2, // QMap<QByteArray,QVariant >
     SBK_QTNETWORK_QLIST_QSSLCIPHER_IDX                       = 3, // QList<QSslCipher >
-    SBK_QTNETWORK_QLIST_QNETWORKPROXY_IDX                    = 4, // QList<QNetworkProxy >
-    SBK_QTNETWORK_QLIST_QNETWORKADDRESSENTRY_IDX             = 5, // QList<QNetworkAddressEntry >
-    SBK_QTNETWORK_QLIST_QHOSTADDRESS_IDX                     = 6, // QList<QHostAddress >
-    SBK_QTNETWORK_QLIST_QNETWORKINTERFACE_IDX                = 7, // QList<QNetworkInterface >
-    SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 8, // QHash<QNetworkRequest::Attribute,QVariant >
-    SBK_QTNETWORK_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX         = 9, // std::pair<QByteArray,QByteArray >
-    SBK_QTNETWORK_QLIST_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX   = 10, // QList<std::pair< QByteArray,QByteArray > >
-    SBK_QTNETWORK_QPAIR_QHOSTADDRESS_INT_IDX                 = 11, // QPair<QHostAddress,int >
+    SBK_QTNETWORK_QLIST_QSSLELLIPTICCURVE_IDX                = 4, // QList<QSslEllipticCurve >
+    SBK_QTNETWORK_QLIST_QNETWORKPROXY_IDX                    = 5, // QList<QNetworkProxy >
+    SBK_QTNETWORK_QLIST_QNETWORKADDRESSENTRY_IDX             = 6, // QList<QNetworkAddressEntry >
+    SBK_QTNETWORK_QLIST_QHOSTADDRESS_IDX                     = 7, // QList<QHostAddress >
+    SBK_QTNETWORK_QLIST_QNETWORKINTERFACE_IDX                = 8, // QList<QNetworkInterface >
+    SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 9, // QHash<QNetworkRequest::Attribute,QVariant >
+    SBK_QTNETWORK_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX         = 10, // std::pair<QByteArray,QByteArray >
+    SBK_QTNETWORK_QLIST_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX   = 11, // QList<std::pair< QByteArray,QByteArray > >
     SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 12, // QHash<QString,QVariant >
     SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 13, // QList<QObject* >
     SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 14, // QList<QNetworkCookie >
@@ -248,16 +262,17 @@ enum : int {
     SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 19, // QList<QDnsMailExchangeRecord >
     SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 20, // QList<QDnsServiceRecord >
     SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 21, // QList<QDnsTextRecord >
-    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 22, // QList<QString >
-    SBK_QTNETWORK_QLIST_QSSL_IMPLEMENTEDCLASS_IDX            = 23, // QList<QSsl::ImplementedClass >
-    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 24, // QList<QOcspResponse >
-    SBK_QTNETWORK_QLIST_QSSL_SUPPORTEDFEATURE_IDX            = 25, // QList<QSsl::SupportedFeature >
-    SBK_QTNETWORK_QLIST_QSSL_SSLPROTOCOL_IDX                 = 26, // QList<QSsl::SslProtocol >
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 27, // QList<QSslCertificateExtension >
-    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 28, // QMultiMap<QSsl::AlternativeNameEntryType,QString >
-    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 29, // QList<QVariant >
-    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 30, // QMap<QString,QVariant >
-    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 31
+    SBK_QTNETWORK_QPAIR_QHOSTADDRESS_INT_IDX                 = 22, // QPair<QHostAddress,int >
+    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 23, // QList<QString >
+    SBK_QTNETWORK_QLIST_QSSL_IMPLEMENTEDCLASS_IDX            = 24, // QList<QSsl::ImplementedClass >
+    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 25, // QList<QOcspResponse >
+    SBK_QTNETWORK_QLIST_QSSL_SUPPORTEDFEATURE_IDX            = 26, // QList<QSsl::SupportedFeature >
+    SBK_QTNETWORK_QLIST_QSSL_SSLPROTOCOL_IDX                 = 27, // QList<QSsl::SslProtocol >
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 28, // QList<QSslCertificateExtension >
+    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 29, // QMultiMap<QSsl::AlternativeNameEntryType,QString >
+    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 30, // QList<QVariant >
+    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 31, // QMap<QString,QVariant >
+    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 32
 };
 // Macros for type check
 
@@ -292,6 +307,7 @@ template<> inline PyTypeObject *SbkType< ::QDnsServiceRecord >() { return reinte
 template<> inline PyTypeObject *SbkType< ::QDnsTextRecord >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QDNSTEXTRECORD_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QDtls::HandshakeState >() { return SbkPySide6_QtNetworkTypes[SBK_QDTLS_HANDSHAKESTATE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QDtls >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QDTLS_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QDtlsClientVerifier >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QDTLSCLIENTVERIFIER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHostAddress::SpecialAddress >() { return SbkPySide6_QtNetworkTypes[SBK_QHOSTADDRESS_SPECIALADDRESS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QHostAddress::ConversionModeFlag >() { return SbkPySide6_QtNetworkTypes[SBK_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QHostAddress::ConversionModeFlag> >() { return SbkPySide6_QtNetworkTypes[SBK_QFLAGS_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX]; }
@@ -301,6 +317,7 @@ template<> inline PyTypeObject *SbkType< ::QHostInfo >() { return reinterpret_ca
 template<> inline PyTypeObject *SbkType< ::QHstsPolicy::PolicyFlag >() { return SbkPySide6_QtNetworkTypes[SBK_QHSTSPOLICY_POLICYFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QHstsPolicy::PolicyFlag> >() { return SbkPySide6_QtNetworkTypes[SBK_QFLAGS_QHSTSPOLICY_POLICYFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QHstsPolicy >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QHSTSPOLICY_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QHttp2Configuration >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QHTTP2CONFIGURATION_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHttpMultiPart::ContentType >() { return SbkPySide6_QtNetworkTypes[SBK_QHTTPMULTIPART_CONTENTTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QHttpMultiPart >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QHTTPMULTIPART_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHttpPart >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QHTTPPART_IDX]); }
@@ -310,6 +327,8 @@ template<> inline PyTypeObject *SbkType< ::QFlags<QLocalServer::SocketOption> >(
 template<> inline PyTypeObject *SbkType< ::QLocalServer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QLOCALSERVER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QLocalSocket::LocalSocketError >() { return SbkPySide6_QtNetworkTypes[SBK_QLOCALSOCKET_LOCALSOCKETERROR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QLocalSocket::LocalSocketState >() { return SbkPySide6_QtNetworkTypes[SBK_QLOCALSOCKET_LOCALSOCKETSTATE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QLocalSocket::SocketOption >() { return SbkPySide6_QtNetworkTypes[SBK_QLOCALSOCKET_SOCKETOPTION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QLocalSocket::SocketOption> >() { return SbkPySide6_QtNetworkTypes[SBK_QFLAGS_QLOCALSOCKET_SOCKETOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QLocalSocket >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QLOCALSOCKET_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkAccessManager::Operation >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_OPERATION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkAccessManager >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_IDX]); }
@@ -322,6 +341,10 @@ template<> inline PyTypeObject *SbkType< ::QNetworkCookie >() { return reinterpr
 template<> inline PyTypeObject *SbkType< ::QNetworkCookieJar >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKCOOKIEJAR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkDatagram >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKDATAGRAM_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkDiskCache >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKDISKCACHE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QNetworkInformation::Reachability >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKINFORMATION_REACHABILITY_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QNetworkInformation::Feature >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKINFORMATION_FEATURE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QNetworkInformation::Feature> >() { return SbkPySide6_QtNetworkTypes[SBK_QFLAGS_QNETWORKINFORMATION_FEATURE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QNetworkInformation >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKINFORMATION_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkInterface::InterfaceFlag >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QNetworkInterface::InterfaceFlag> >() { return SbkPySide6_QtNetworkTypes[SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkInterface::InterfaceType >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKINTERFACE_INTERFACETYPE_IDX]; }
@@ -364,6 +387,7 @@ template<> inline PyTypeObject *SbkType< ::QSslConfiguration::NextProtocolNegoti
 template<> inline PyTypeObject *SbkType< ::QSslConfiguration >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLCONFIGURATION_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSslDiffieHellmanParameters::Error >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslDiffieHellmanParameters >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QSslEllipticCurve >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLELLIPTICCURVE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSslError::SslError >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLERROR_SSLERROR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslError >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLERROR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSslKey >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLKEY_IDX]); }
