@@ -49,13 +49,13 @@
 // Module Includes
 #include <pyside6_qtcore_python.h>
 #include <pyside6_qtnetwork_python.h>
-#include <pyside6_qtgui_python.h>
 
 // Bound library includes
 #include <QtQml/qqmlexpression.h>
 #include <QtQml/qqmlengine.h>
-#include <QtQml/qqmlcomponent.h>
+#include <QtQml/qjsprimitivevalue.h>
 #include <QtQml/qqml.h>
+#include <QtQml/qqmlcomponent.h>
 #include <QtQml/qqmldebug.h>
 #include <QtQml/qqmlapplicationengine.h>
 #include <QtQml/qqmlnetworkaccessmanagerfactory.h>
@@ -71,12 +71,14 @@
 #include <QtQml/qjsengine.h>
 #include <QtQml/qqmlincubator.h>
 #include <QtQml/qqmlfile.h>
+#include <QtQml/qjsmanagedvalue.h>
 #include <QtQml/qqmlpropertymap.h>
 #include <QtQml/qqmlpropertyvaluesource.h>
 #include <QtQml/qqmlfileselector.h>
 #include <QtQml/qqmlcontext.h>
 #include <QtQml/qqmlextensioninterface.h>
 // Conversion Includes - Primitive Types
+#include <QAnyStringView>
 #include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
@@ -87,6 +89,7 @@
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
@@ -111,49 +114,53 @@ enum : int {
     SBK_QJSENGINE_EXTENSION_IDX                              = 3,
     SBK_QFLAGS_QJSENGINE_EXTENSION_IDX                       = 0,
     SBK_QJSENGINE_IDX                                        = 2,
-    SBK_QJSVALUE_SPECIALVALUE_IDX                            = 8,
-    SBK_QJSVALUE_ERRORTYPE_IDX                               = 6,
-    SBK_QJSVALUE_OBJECTCONVERSIONBEHAVIOR_IDX                = 7,
-    SBK_QJSVALUE_IDX                                         = 5,
-    SBK_QJSVALUEITERATOR_IDX                                 = 9,
-    SBK_QQMLABSTRACTURLINTERCEPTOR_DATATYPE_IDX              = 12,
-    SBK_QQMLABSTRACTURLINTERCEPTOR_IDX                       = 11,
-    SBK_QQMLAPPLICATIONENGINE_IDX                            = 13,
-    SBK_QQMLCOMPONENT_COMPILATIONMODE_IDX                    = 15,
-    SBK_QQMLCOMPONENT_STATUS_IDX                             = 16,
-    SBK_QQMLCOMPONENT_IDX                                    = 14,
-    SBK_QQMLCONTEXT_IDX                                      = 17,
-    SBK_QQMLDEBUGGINGENABLER_STARTMODE_IDX                   = 19,
-    SBK_QQMLDEBUGGINGENABLER_IDX                             = 18,
-    SBK_QQMLENGINE_IDX                                       = 20,
-    SBK_QQMLERROR_IDX                                        = 21,
-    SBK_QQMLEXPRESSION_IDX                                   = 22,
-    SBK_QQMLEXTENSIONINTERFACE_IDX                           = 23,
-    SBK_QQMLEXTENSIONPLUGIN_IDX                              = 24,
-    SBK_QQMLFILE_STATUS_IDX                                  = 26,
-    SBK_QQMLFILE_IDX                                         = 25,
-    SBK_QQMLFILESELECTOR_IDX                                 = 27,
-    SBK_QQMLIMAGEPROVIDERBASE_IMAGETYPE_IDX                  = 30,
-    SBK_QQMLIMAGEPROVIDERBASE_FLAG_IDX                       = 29,
+    SBK_QJSMANAGEDVALUE_TYPE_IDX                             = 6,
+    SBK_QJSMANAGEDVALUE_IDX                                  = 5,
+    SBK_QJSPRIMITIVEVALUE_TYPE_IDX                           = 8,
+    SBK_QJSPRIMITIVEVALUE_IDX                                = 7,
+    SBK_QJSVALUE_SPECIALVALUE_IDX                            = 12,
+    SBK_QJSVALUE_ERRORTYPE_IDX                               = 10,
+    SBK_QJSVALUE_OBJECTCONVERSIONBEHAVIOR_IDX                = 11,
+    SBK_QJSVALUE_IDX                                         = 9,
+    SBK_QJSVALUEITERATOR_IDX                                 = 13,
+    SBK_QQMLABSTRACTURLINTERCEPTOR_DATATYPE_IDX              = 16,
+    SBK_QQMLABSTRACTURLINTERCEPTOR_IDX                       = 15,
+    SBK_QQMLAPPLICATIONENGINE_IDX                            = 17,
+    SBK_QQMLCOMPONENT_COMPILATIONMODE_IDX                    = 19,
+    SBK_QQMLCOMPONENT_STATUS_IDX                             = 20,
+    SBK_QQMLCOMPONENT_IDX                                    = 18,
+    SBK_QQMLCONTEXT_IDX                                      = 21,
+    SBK_QQMLDEBUGGINGENABLER_STARTMODE_IDX                   = 23,
+    SBK_QQMLDEBUGGINGENABLER_IDX                             = 22,
+    SBK_QQMLENGINE_IDX                                       = 24,
+    SBK_QQMLERROR_IDX                                        = 25,
+    SBK_QQMLEXPRESSION_IDX                                   = 26,
+    SBK_QQMLEXTENSIONINTERFACE_IDX                           = 27,
+    SBK_QQMLEXTENSIONPLUGIN_IDX                              = 28,
+    SBK_QQMLFILE_STATUS_IDX                                  = 30,
+    SBK_QQMLFILE_IDX                                         = 29,
+    SBK_QQMLFILESELECTOR_IDX                                 = 31,
+    SBK_QQMLIMAGEPROVIDERBASE_IMAGETYPE_IDX                  = 34,
+    SBK_QQMLIMAGEPROVIDERBASE_FLAG_IDX                       = 33,
     SBK_QFLAGS_QQMLIMAGEPROVIDERBASE_FLAG_IDX                = 1,
-    SBK_QQMLIMAGEPROVIDERBASE_IDX                            = 28,
-    SBK_QQMLINCUBATIONCONTROLLER_IDX                         = 31,
-    SBK_QQMLINCUBATOR_INCUBATIONMODE_IDX                     = 33,
-    SBK_QQMLINCUBATOR_STATUS_IDX                             = 34,
-    SBK_QQMLINCUBATOR_IDX                                    = 32,
-    SBK_QQMLLISTREFERENCE_IDX                                = 35,
-    SBK_QQMLNETWORKACCESSMANAGERFACTORY_IDX                  = 37,
-    SBK_QQMLPARSERSTATUS_IDX                                 = 38,
-    SBK_QQMLPROPERTY_PROPERTYTYPECATEGORY_IDX                = 40,
-    SBK_QQMLPROPERTY_TYPE_IDX                                = 41,
-    SBK_QQMLPROPERTY_IDX                                     = 39,
-    SBK_QQMLPROPERTYMAP_IDX                                  = 42,
-    SBK_QQMLPROPERTYVALUESOURCE_IDX                          = 43,
-    SBK_QQMLSCRIPTSTRING_IDX                                 = 44,
-    SBK_QQMLTYPESEXTENSIONINTERFACE_IDX                      = 45,
-    SBK_QML_HAS_ATTACHED_PROPERTIES_IDX                      = 10,
-    SBK_QQMLMODULEIMPORTSPECIALVERSIONS_IDX                  = 36,
-    SBK_QtQml_IDX_COUNT                                      = 47
+    SBK_QQMLIMAGEPROVIDERBASE_IDX                            = 32,
+    SBK_QQMLINCUBATIONCONTROLLER_IDX                         = 35,
+    SBK_QQMLINCUBATOR_INCUBATIONMODE_IDX                     = 37,
+    SBK_QQMLINCUBATOR_STATUS_IDX                             = 38,
+    SBK_QQMLINCUBATOR_IDX                                    = 36,
+    SBK_QQMLLISTREFERENCE_IDX                                = 39,
+    SBK_QQMLNETWORKACCESSMANAGERFACTORY_IDX                  = 41,
+    SBK_QQMLPARSERSTATUS_IDX                                 = 42,
+    SBK_QQMLPROPERTY_PROPERTYTYPECATEGORY_IDX                = 44,
+    SBK_QQMLPROPERTY_TYPE_IDX                                = 45,
+    SBK_QQMLPROPERTY_IDX                                     = 43,
+    SBK_QQMLPROPERTYMAP_IDX                                  = 46,
+    SBK_QQMLPROPERTYVALUESOURCE_IDX                          = 47,
+    SBK_QQMLSCRIPTSTRING_IDX                                 = 48,
+    SBK_QQMLTYPESEXTENSIONINTERFACE_IDX                      = 49,
+    SBK_QML_HAS_ATTACHED_PROPERTIES_IDX                      = 14,
+    SBK_QQMLMODULEIMPORTSPECIALVERSIONS_IDX                  = 40,
+    SBK_QtQml_IDX_COUNT                                      = 51
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtQmlTypes;
@@ -172,9 +179,10 @@ enum : int {
     SBK_QTQML_QLIST_QJSVALUE_IDX                             = 3, // QList<QJSValue >
     SBK_QTQML_QLIST_QOBJECTPTR_IDX                           = 4, // QList<QObject* >
     SBK_QTQML_QLIST_QBYTEARRAY_IDX                           = 5, // QList<QByteArray >
-    SBK_QTQML_QLIST_QVARIANT_IDX                             = 6, // QList<QVariant >
-    SBK_QTQML_QLIST_QSTRING_IDX                              = 7, // QList<QString >
-    SBK_QtQml_CONVERTERS_IDX_COUNT                           = 8
+    SBK_QTQML_QLIST_QQMLABSTRACTURLINTERCEPTORPTR_IDX        = 6, // QList<QQmlAbstractUrlInterceptor* >
+    SBK_QTQML_QLIST_QVARIANT_IDX                             = 7, // QList<QVariant >
+    SBK_QTQML_QLIST_QSTRING_IDX                              = 8, // QList<QString >
+    SBK_QtQml_CONVERTERS_IDX_COUNT                           = 9
 };
 // Macros for type check
 
@@ -189,6 +197,10 @@ template<> inline PyTypeObject *SbkType< ::QJSEngine::ObjectOwnership >() { retu
 template<> inline PyTypeObject *SbkType< ::QJSEngine::Extension >() { return SbkPySide6_QtQmlTypes[SBK_QJSENGINE_EXTENSION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QJSEngine::Extension> >() { return SbkPySide6_QtQmlTypes[SBK_QFLAGS_QJSENGINE_EXTENSION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QJSEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QJSENGINE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QJSManagedValue::Type >() { return SbkPySide6_QtQmlTypes[SBK_QJSMANAGEDVALUE_TYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QJSManagedValue >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QJSMANAGEDVALUE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QJSPrimitiveValue::Type >() { return SbkPySide6_QtQmlTypes[SBK_QJSPRIMITIVEVALUE_TYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QJSPrimitiveValue >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQmlTypes[SBK_QJSPRIMITIVEVALUE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QJSValue::SpecialValue >() { return SbkPySide6_QtQmlTypes[SBK_QJSVALUE_SPECIALVALUE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QJSValue::ErrorType >() { return SbkPySide6_QtQmlTypes[SBK_QJSVALUE_ERRORTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QJSValue::ObjectConversionBehavior >() { return SbkPySide6_QtQmlTypes[SBK_QJSVALUE_OBJECTCONVERSIONBEHAVIOR_IDX]; }
